using System;

using Microsoft.Practices.EnterpriseLibrary.Logging;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;

namespace BennettAdelson.Sig.Common {
	public class TraceWriter : IDisposable {
		private Tracer _tracer;
		private bool _needsDisposed = true;

		public TraceWriter(string operation) {
			_tracer = new Tracer(operation);
		}
		
		public TraceWriter(string operation, Guid activityId) {
			_tracer = new Tracer(operation, activityId);
		}

		public void Dispose() {
			Dispose(true);
		}

		protected virtual void Dispose(bool disposing) {
			if (_needsDisposed) {
				if (disposing) {
					if (_tracer != null)
						_tracer.Dispose();

					GC.SuppressFinalize(this);
				}

				_needsDisposed = false;
			}
		}

		~TraceWriter() {
			Dispose(false);
		}

		public bool IsTracingEnabled() {
			bool ret = false;

			if (_tracer != null)
				ret = _tracer.IsTracingEnabled();

			return ret;
		}
	}
}
